@@ -1,7 +1,7 @@
 import requests
 import subprocess
 
-from .errors import error_handler
+from AuthGG.errors import error_handler
 
 class Client:
     def __init__(self, api_key, aid, application_secret):
